@@ -11,5 +11,5 @@
 
 
 
-from gym_update.envs.update_env import UpdateEnv
+from gym_update.envs.doc2_0 import DocEnv
 
